'use strict';

var pluginScaffolderNode = require('@backstage/plugin-scaffolder-node');
var errors = require('@backstage/errors');

function createSentryCreateProjectAction(options) {
  const { config } = options;
  return pluginScaffolderNode.createTemplateAction({
    id: "sentry:project:create",
    schema: {
      input: {
        required: ["organizationSlug", "teamSlug", "name"],
        type: "object",
        properties: {
          organizationSlug: {
            title: "The slug of the organization the team belongs to",
            type: "string"
          },
          teamSlug: {
            title: "The slug of the team to create a new project for",
            type: "string"
          },
          name: {
            title: "The name for the new project",
            type: "string"
          },
          slug: {
            title: "Optional slug for the new project. If not provided a slug is generated from the name",
            type: "string"
          },
          authToken: {
            title: "authenticate via bearer auth token. Requires scope: project:write",
            type: "string"
          }
        }
      }
    },
    async handler(ctx) {
      const { organizationSlug, teamSlug, name, slug, authToken } = ctx.input;
      const body = {
        name
      };
      if (slug) {
        body.slug = slug;
      }
      const token = authToken ? authToken : config.getOptionalString("scaffolder.sentry.token");
      if (!token) {
        throw new errors.InputError(`No valid sentry token given`);
      }
      const response = await fetch(
        `https://sentry.io/api/0/teams/${organizationSlug}/${teamSlug}/projects/`,
        {
          method: "POST",
          headers: {
            Authorization: `Bearer ${token}`,
            "Content-Type": "application/json"
          },
          body: JSON.stringify(body)
        }
      );
      const contentType = response.headers.get("content-type");
      if (contentType !== "application/json") {
        throw new errors.InputError(
          `Unexpected Sentry Response Type: ${await response.text()}`
        );
      }
      const code = response.status;
      const result = await response.json();
      if (code !== 201) {
        throw new errors.InputError(`Sentry Response was: ${await result.detail}`);
      }
      ctx.output("id", result.id);
      ctx.output("result", result);
    }
  });
}

exports.createSentryCreateProjectAction = createSentryCreateProjectAction;
//# sourceMappingURL=createProject.cjs.js.map
